netapp_ontap.models.nfs_service_credential_cache API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nfs_service_credential_cache`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NfsServiceCredentialCacheSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NfsServiceCredentialCache object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `harvest_timeout: Size GET POST PATCH`

    Specifies the age of the unused cached entries, in milliseconds, after which they are cleared from the cache.

    Example: 86400000

  `negative_ttl: Size GET POST PATCH`

    Specifies the age in milliseconds, of the negative cached credentials after which they are cleared from the cache.

    Example: 3600000

  `positive_ttl: Size GET POST PATCH`

    Specifies the age in milliseconds, of the positive cached credentials after which they are cleared from the cache.

    Example: 3600000

  `transient_error_ttl: Size GET POST PATCH`

    Specifies the age in milliseconds, of the cached entries during a transient error situation.

    Example: 30000